California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 68 - TRIBAL GAMING COMPACT RENEGOTIATION. NON-TRIBAL COMMERCIAL GAMBLING EXPANSION. REVENUES, TAX EXEMPTIONS. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1269307 | UNITE HERE, AFL- CIO, NO ON PROPOSITIONS 68 AND 70 COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1262193 | FIRST CALIFORNIANS FOR SELF RELIANCE, NO ON 68, A COALITION OF THE MORONGO, PALA, RUMSEY, UNITED AUBURN AND VIEJAS GAMING TRIBES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1260733 | YES ON 68, A FAIR SHARE FOR CALIFORNIA, A COALITION OF LAW ENFORCEMENT, EDUCATORS AND LABOR, SUPPORTED BY HORSE RACING AND CARD CLUBS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261021 | CALIFORNIANS FOR INDIAN SELF-RELIANCE, SPONSORED BY CALIFORNIA INDIAN TRIBES (TRIBAL GAMING), NO ON PROP. 68 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261851 | NO ON 68: CALIFORNIANS AGAINST THE DECEPTIVE GAMBLING PROPOSITION, A COALITION OF INDIAN GAMING TRIBES | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1266181 | NO ON 68 & 70 - GOVERNOR SCHWARZENEGGER'S COMMITTEE FOR FAIR SHARE GAMING AGREEMENTS | OPPOSE